@@ -246,6 +246,7 @@ class Tests(unittest.TestCase):
         from check_manifest import strip_sdist_extras
         filelist = list(map(os.path.normpath, [
             '.gitignore',
+            '.travis.yml',
             'setup.py',
             'setup.cfg',
             'README.txt',
@@ -370,11 +371,13 @@ class Tests(unittest.TestCase):
             'docs/image.png',
             'docs/Makefile',
             'docs/unknown-file',
+            'src/etc/blah/blah/Makefile',
         ]))
         expected_rules = [
             'recursive-include docs *.png',
             'recursive-include docs *.rst',
             'recursive-include docs Makefile',
+            'recursive-include src Makefile',
         ]
         expected_unknowns = [os.path.normpath('docs/unknown-file')]
         self.assertEqual(find_suggestions(filelist),
@@ -457,6 +460,9 @@ class Tests(unittest.TestCase):
         # not fail over it or end up with double slashes.
         self.assertEqual(parse('prune dir/'),
                          (['dir', j('dir', '*')], []))
+        # You should also not have a leading slash
+        self.assertEqual(parse('prune /dir'),
+                         (['/dir', j('/dir', '*')], []))
         # And a mongo test case of everything at the end
         text = textwrap.dedent("""
             #exclude *.01
@@ -594,6 +600,7 @@ class TestMain(unittest.TestCase):
 
     def test(self):
         from check_manifest import main
+        sys.argv.append('-v')
         main()
 
     def test_exit_code_1_on_error(self):
@@ -875,44 +882,87 @@ class TestSvn(VCSMixin, unittest.TestCase):
 class TestUserInterface(unittest.TestCase):
 
     def setUp(self):
+        import check_manifest
+        self.old_VERBOSE = check_manifest.VERBOSE
         self.real_stdout = sys.stdout
         self.real_stderr = sys.stderr
         sys.stdout = StringIO()
         sys.stderr = StringIO()
 
     def tearDown(self):
+        import check_manifest
         sys.stderr = self.real_stderr
         sys.stdout = self.real_stdout
+        check_manifest.VERBOSE = self.old_VERBOSE
 
     def test_info(self):
-        from check_manifest import info
-        info("Reticulating splines")
+        import check_manifest
+        check_manifest.VERBOSE = False
+        check_manifest.info("Reticulating splines")
+        self.assertEqual(sys.stdout.getvalue(),
+                         "Reticulating splines\n")
+
+    def test_info_verbose(self):
+        import check_manifest
+        check_manifest.VERBOSE = True
+        check_manifest.info("Reticulating splines")
         self.assertEqual(sys.stdout.getvalue(),
                          "Reticulating splines\n")
 
     def test_info_begin_continue_end(self):
-        from check_manifest import info_begin, info_continue, info_end
-        info_begin("Reticulating splines...")
-        info_continue(" nearly done...")
-        info_continue(" almost done...")
-        info_end(" done!")
+        import check_manifest
+        check_manifest.VERBOSE = False
+        check_manifest.info_begin("Reticulating splines...")
+        check_manifest.info_continue(" nearly done...")
+        check_manifest.info_continue(" almost done...")
+        check_manifest.info_end(" done!")
+        self.assertEqual(sys.stdout.getvalue(), "")
+
+    def test_info_begin_continue_end_verbose(self):
+        import check_manifest
+        check_manifest.VERBOSE = True
+        check_manifest.info_begin("Reticulating splines...")
+        check_manifest.info_continue(" nearly done...")
+        check_manifest.info_continue(" almost done...")
+        check_manifest.info_end(" done!")
         self.assertEqual(
             sys.stdout.getvalue(),
             "Reticulating splines... nearly done... almost done... done!\n")
 
     def test_info_emits_newline_when_needed(self):
-        from check_manifest import info_begin, info
-        info_begin("Computering...")
-        info("Forgot to turn the gas off!")
+        import check_manifest
+        check_manifest.VERBOSE = False
+        check_manifest.info_begin("Computering...")
+        check_manifest.info("Forgot to turn the gas off!")
+        self.assertEqual(
+            sys.stdout.getvalue(),
+            "Forgot to turn the gas off!\n")
+
+    def test_info_emits_newline_when_needed_verbose(self):
+        import check_manifest
+        check_manifest.VERBOSE = True
+        check_manifest.info_begin("Computering...")
+        check_manifest.info("Forgot to turn the gas off!")
         self.assertEqual(
             sys.stdout.getvalue(),
             "Computering...\n"
             "Forgot to turn the gas off!\n")
 
     def test_warning(self):
-        from check_manifest import info_begin, warning
-        info_begin("Computering...")
-        warning("Forgot to turn the gas off!")
+        import check_manifest
+        check_manifest.VERBOSE = False
+        check_manifest.info_begin("Computering...")
+        check_manifest.warning("Forgot to turn the gas off!")
+        self.assertEqual(sys.stdout.getvalue(), "")
+        self.assertEqual(
+            sys.stderr.getvalue(),
+            "Forgot to turn the gas off!\n")
+
+    def test_warning_verbose(self):
+        import check_manifest
+        check_manifest.VERBOSE = True
+        check_manifest.info_begin("Computering...")
+        check_manifest.warning("Forgot to turn the gas off!")
         self.assertEqual(
             sys.stdout.getvalue(),
             "Computering...\n")
@@ -921,9 +971,20 @@ class TestUserInterface(unittest.TestCase):
             "Forgot to turn the gas off!\n")
 
     def test_error(self):
-        from check_manifest import info_begin, error
-        info_begin("Computering...")
-        error("Forgot to turn the gas off!")
+        import check_manifest
+        check_manifest.VERBOSE = False
+        check_manifest.info_begin("Computering...")
+        check_manifest.error("Forgot to turn the gas off!")
+        self.assertEqual(sys.stdout.getvalue(), "")
+        self.assertEqual(
+            sys.stderr.getvalue(),
+            "Forgot to turn the gas off!\n")
+
+    def test_error_verbose(self):
+        import check_manifest
+        check_manifest.VERBOSE = True
+        check_manifest.info_begin("Computering...")
+        check_manifest.error("Forgot to turn the gas off!")
         self.assertEqual(
             sys.stdout.getvalue(),
             "Computering...\n")
@@ -987,6 +1048,15 @@ class TestCheckManifest(unittest.TestCase):
         os.chdir(os.pardir)
         self.assertTrue(check_manifest('subdir'))
 
+    def test_relative_python(self):
+        from check_manifest import check_manifest
+        os.mkdir('subdir')
+        os.chdir('subdir')
+        self._create_repo_with_code()
+        os.chdir(os.pardir)
+        python = os.path.relpath(sys.executable)
+        self.assertTrue(check_manifest('subdir', python=python))
+
     def test_suggestions(self):
         from check_manifest import check_manifest
         self._create_repo_with_code()
@@ -1074,6 +1144,15 @@ class TestCheckManifest(unittest.TestCase):
         self.assertIn("this also applies to the following:\n  moo.mo",
                       sys.stderr.getvalue())
 
+    def test_missing_source_files(self):
+        from check_manifest import check_manifest
+        self._create_repo_with_code()
+        self._add_to_vcs('missing.py')
+        os.unlink('missing.py')
+        check_manifest()
+        self.assertIn("some files listed as being under source control are missing:\n  missing.py",
+                      sys.stderr.getvalue())
+
 
 def test_suite():
     return unittest.TestSuite([
